<template>
  <div>
    <card>
      <Form
        ref="searchForm"
        @keydown.enter.native="handleSearch"
        :model="searchForm"
        inline
        :label-width="70"
        class="search-form"
      >
        <Form-item label="用户名" prop="username">
          <Input
            type="text"
            v-model="searchForm.username"
            clearable
            @on-clear="handleSearch"
            @on-change="handleSearch"
            style="width: 160px"
          />
        </Form-item>
        <Form-item label="昵称" prop="nickname">
          <Input
            type="text"
            v-model="searchForm.nickName"
            clearable
            @on-clear="handleSearch"
            @on-change="handleSearch"
            style="width: 160px"
          />
        </Form-item>
        <Form-item label="商家" prop="storeId">
          <Select
            v-model="searchForm.storeId"
            style="width:160px"
            :loading="storeSelectLoading"
            class="custom-select"
            clearable
            @on-clear="handleSearch"
            @on-change="handleSearch"
          >
            <Option
              v-for="item in selectOptions"
              :value="item.id"
              :key="item.id"
            >
              {{ item.storeName }}
            </Option>
          </Select>
        </Form-item>
        <Button
          @click="handleSearch"
          type="primary"
          icon="ios-search"
          class="search-btn"
        >搜索</Button
        >
      </Form>

      <Table
        :loading="loading"
        border
        :columns="columns"
        :data="customerList"
        ref="table"
        sortable="custom"
        @on-sort-change="changeSort"
        @on-selection-change="showSelect"
      >
        <template slot-scope="{ row, index }" slot="action">
          <Button type="info" size="small" style="margin-right: 5px" @click="openInfo(row)">查看详情</Button>
          <Button type="info" size="small" style="margin-right: 5px" @click="openEdit(row)">编辑标签</Button>
          <Button type="error" size="small" style="margin-right: 5px" @click="joinBlack(row)">加入黑名单</Button>
        </template>
      </Table>
      <Row type="flex" justify="end" class="mt_10">
        <Page
          :current="searchForm.pageNumber"
          :total="total"
          :page-size="searchForm.pageSize"
          @on-change="changePage"
          @on-page-size-change="changePageSize"
          :page-size-opts="[10, 20, 50]"
          size="small"
          show-total
          show-elevator
          show-sizer
        ></Page>
      </Row>

      <Modal
        v-model="showCustomerInfo"
        :title="modelTitle"
        width="700"
        :mask-closable="false"
      >
        <div class="customer-detail">
          <div class="avatar-section">
            <Avatar :src="customerInfo.face" size="large" />
            <div class="basic-info">
              <h3>{{ customerInfo.nickName || '微信用户' }}</h3>
              <p>ID: {{ customerInfo.id }}</p>
              <p>用户名: {{ customerInfo.username }}</p>
            </div>
          </div>

          <Divider />

          <div class="detail-grid">
            <div class="detail-row">
              <span class="detail-label">性别：</span>
              <span class="detail-value">{{ customerInfo.sex === 0 ? "女" : "男"}}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">地区：</span>
              <span class="detail-value">{{ customerInfo.region || '未设置' }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">手机号：</span>
              <span class="detail-value">{{ customerInfo.mobile || '未绑定' }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">当前积分：</span>
              <span class="detail-value">{{ customerInfo.point }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">总积分：</span>
              <span class="detail-value">{{ customerInfo.totalPoint }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">账号状态：</span>
              <span class="detail-value">
          <Tag :color="customerInfo.disabled ? 'error' : 'success'">
            {{ customerInfo.disabled ? '已禁用' : '正常' }}
          </Tag>
        </span>
            </div>
            <div class="detail-row">
              <span class="detail-label">是否关联店铺：</span>
              <span class="detail-value">{{ customerInfo.haveStore ? '是' : '否' }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">注册时间：</span>
              <span class="detail-value">{{ customerInfo.createTime }}</span>
            </div>
            <div class="detail-row">
              <span class="detail-label">最后登录时间：</span>
              <span class="detail-value">{{ customerInfo.lastLoginDate }}</span>
            </div>
          </div>

          <div v-if="customerInfo.customerTagList && customerInfo.customerTagList.length > 0" class="tags-section">
            <h4>用户标签</h4>
            <div>
              <Tag v-for="tag in customerInfo.customerTagList" :key="tag" color="default" style="margin-right: 8px;">
                {{ tag }}
              </Tag>
            </div>
          </div>
        </div>

        <div slot="footer">
          <Button type="primary" @click="showCustomerInfo = false">关闭</Button>
        </div>
      </Modal>
<!--      标签弹窗-->
      <Modal
        v-model="showCustomerTag"
        :title="modelTitle"
      >
        <Form ref="form" :model="tagForm" :label-width="70" :rules="rules">
          <FormItem label="标签名称" prop="tagList">
              <Select
                v-model="tagForm.tagList"
                multiple
                style="width:260px"
                :loading="selectLoading"
                class="custom-select"
                @on-clear="handleRemoveTag"
                @on-select="handleSelectChange"
              >
                <Option
                  v-for="item in tagList"
                  :value="item.id"
                  :key="item.id"
                >
                  {{ item.tagName }}
                </Option>
              </Select>
          </FormItem>
        </Form>
        <div slot="footer">
          <Button type="text" @click="modelClose">确定</Button>
<!--          <Button type="primary" :loading="submitLoading" @click="saveOrUpdate">提交</Button>-->
        </div>
      </Modal>
    </card>


  </div>
</template>

<script>
import JsonExcel from "vue-json-excel";
import {getCustomerList,addCustomerTag,saveCustomerTagById,getTagList,getStoreSelectOptions,getCustomerInfo} from "@/api/customer";
import {addCustomerBlackByPC} from "@/api/customer-black.js"

export default {
  name:"customer",
  components:{
    "download-excel": JsonExcel,
  },
  data(){
    return{
      customerInfo: {
        birthday: null,
        blackId: null,
        clientEnum: null,
        createTime: "",
        customerTagList: [],
        disabled: true,
        experience: null,
        face: "",
        gradeId: null,
        haveStore: false,
        id: "",
        lastLoginDate: "",
        mobile: null,
        nickName: "",
        openId: null,
        point: 10,
        region: "",
        regionId: "",
        sex: 0,
        storeId: null,
        totalPoint: 0,
        username: ""
      },
      loading: false, // 表单加载状态
      //查询客户列表请求参数
      searchForm:{
        storeId: '', //商家
        username:'', //用户名
        nickName:'', // 昵称
        pageNumber: 1, // 当前页数
        pageSize: 10, // 页面大小
      },
      //客户列表表头
      columns: [
        {
          type: 'selection',
          width: 60,
          align: 'center'
        },
        {
          title:'用户名',
          key: 'username',
          minWidth: 60,
          tooltip: true,
        },
        {
          title:'昵称',
          key: 'nickName',
          minWidth: 60,
          tooltip: true,
        },
        {
          title:'性别',
          key: 'sex',
          tooltip: true,
          render: (h, params) => {
            const sexText = params.row.sex === 1 ? '男' : '女';
            return h('span', sexText);
          }
        },
        {
          title:'地址',
          key: 'region',
          minWidth: 60,
          tooltip: true,
        },
        {
          title:'状态',
          key: 'disabled',
          tooltip: true,
          render: (h, params) => {
            const sexText = params.row.disabled === true ? '禁用' : '正常';
            return h('span', sexText);
          }
        },
        {
          title:'客户标签',
          key: 'customerTagList',
          minWidth: 60,
          tooltip: true,
          render: (h, params) => {
            const tags = params.row.customerTagList || [];
            return h('div', {
              style: {
                display: 'flex',
                flexWrap: 'wrap', // 允许换行
                gap: '4px' // 标签间距
              }
            }, tags.map(tag => {
              return h('Tag', {
                props: {
                  color: tag.color || 'default', // 假设标签有颜色字段
                  size: 'small'
                }
              }, tag.name); // 假设标签对象有name字段
            }));
          }
        },
        {
          title: '操作',
          key: 'action',
          slot: 'action',
          minWidth: 150,
          align: 'center'
        }

      ],
      //客户列表数据
      customerList:[],
      total:0,
      selectCount: 0, // 已选数量
      selectList: [], // 已选数据列表

      //客户详情对话框---
      showCustomerInfo:false,
      //客户标签对话框---
      showCustomerTag:false,
      submitLoading:false,
      selectLoading:false,
      modelTitle:'',
      tagList:[],
      tagForm:{
        id: '',
        tagList: [],
        createType: 'SYSTEM'
      },
      rules: {
        tagList: [
          {required: true, message: "标签名称不能为空", trigger: "blur", type: 'array'}
        ],
      },
      //商家下拉框数据
      selectOptions:[],
      storeSelectLoading: false,

      //黑名单请求对象
      blackParam:{
        storeId:'',
        userId:'',
      }

    }
  },
  mounted(){
    this.init();
  },
  methods:{
    // 获得商家下拉框数据
    getStoreSelectOptions(){
      this.storeSelectLoading = true;
      getStoreSelectOptions().then(res =>{
        this.storeSelectLoading = false;
        if (res.code === 200){
          this.selectOptions = res.data;
        }
      })
    },
    // 获得客户表格信息
    getCustomerList(){
      this.loading = true;
      getCustomerList(this.searchForm).then(res =>{
        this.loading = false;
        if (res.code === 200) {
          this.customerList = res.data;
          this.total = res.total;
        }
      })
    },
    // 获得客户标签下拉框数据
    getCustomerTagSelectOptions(){
      this.selectLoading = true;
      getTagList().then(res =>{
        this.selectLoading = false;
        if (res.code === 200){
          this.tagList = res.data;
        }
      })
    },
    init(){
      this.getCustomerList();
      this.getCustomerTagSelectOptions();
      this.getStoreSelectOptions();
    },
    changeSort(){

    },
    showSelect(){
      this.selectList = e.map(d => d.id);
      this.selectCount = e.length;
    },
    //查看详情
    openInfo(row){
      this.showCustomerInfo = true;
      this.modelTitle = "用户详情"
      getCustomerInfo(row.id).then(res =>{
        if(res.code === 200){
          this.customerInfo = {
            birthday: res.data.birthday || null,
            blackId: res.data.blackId || null,
            clientEnum: res.data.clientEnum || null,
            createTime: res.data.createTime || '',
            customerTagList: res.data.customerTagList || [],
            disabled: res.data.disabled || false,
            experience: res.data.experience || null,
            face: res.data.face || '默认头像URL',
            gradeId: res.data.gradeId || null,
            haveStore: res.data.haveStore || false,
            id: res.data.id || '',
            lastLoginDate: res.data.lastLoginDate || '',
            mobile: res.data.mobile || null,
            nickName: res.data.nickName || '微信用户',
            openId: res.data.openId || null,
            point: res.data.point || 0,
            region: res.data.region || '',
            regionId: res.data.regionId || '',
            sex: res.data.sex || 0,
            storeId: res.data.storeId || null,
            totalPoint: res.data.totalPoint || 0,
            username: res.data.username || ''
          };
        }
      })
    },
    // 编辑标签
    openEdit(row){
      this.showCustomerTag = true
      this.modelTitle = "编辑标签"
      //放入form
      this.tagForm.id = row.id
      this.tagForm.tagList = row.customerTagList


    },
    handleSearch(){
      this.searchForm.pageNumber = 1;
      this.searchForm.pageSize = 10;
      this.getCustomerList();
    },
    handleSelectChange(newVal){
      console.log(newVal)
      this.getCustomerList()
    },
    handleRemoveTag(removedTag) {
      console.log(removedTag)
      this.getCustomerList()
    },
    // 关闭弹窗
    modelClose() {
      this.submitLoading = false
      this.showCustomerTag = false
    },

    delById(){

    },
    // 页码
    changePage(v){
      this.searchForm.pageNumber = v
      this.getCustomerList()
    },
    // 修改size
    changePageSize(v){
      this.searchForm.pageNumber = 1;
      this.searchForm.pageSize = v;
      this.getCustomerList()
    },
    joinBlack(row){
      this.blackParam.storeId = row.storeId;
      this.blackParam.userId = row.id;
      addCustomerBlackByPC(this.blackParam).then(res =>{
        if (res.code === 200){
          this.$Message.success(res.msg);
        }
      })
    },


  }
}

</script>
<style lang="scss" scoped>
.customer-detail {
  padding: 16px;
}

.avatar-section {
  display: flex;
  align-items: center;
  margin-bottom: 16px;
}

.basic-info {
  margin-left: 16px;
}

.basic-info h3 {
  margin: 0 0 8px 0;
  font-size: 18px;
}

.basic-info p {
  margin: 6px 0;
  color: #808695;
  font-size: 14px;
}

.tags-section {
  margin-top: 16px;
  padding-top: 16px;
}

.tags-section h4 {
  margin-bottom: 12px;
  color: #17233d;
}
.export {
  margin: 10px 20px 10px 0;
}
.export-excel-wrapper {
  display: inline;
}
.order-tab {
  width: 950px;
  height: 36px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  background-color: #f0f0f0;
  padding: 0 10px;
  margin-bottom: 10px;
  div {
    text-align: center;
    padding: 4px 12px;
    border-radius: 4px;
    cursor: pointer;
  }
  .current {
    background-color: #ffffff;
  }
}
</style>

